==> jc-1.4.0.tar.gz: gnu/java/security/action/SetAccessibleAction.h <==
// public class gnu.java.security.action.SetAccessibleAction

// class file dependencies
// @dep_class a46aa76484d70b7e gnu_java_security_action_SetAccessibleAction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_action_SetAccessibleAction_H_
#define _JC_gnu_java_security_action_SetAccessibleAction_H_

// Forward structure declarations
struct _jc_gnu_java_security_action_SetAccessibleAction$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_reflect_AccessibleObject$object;

// Typedefs
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$sub_refs	_jc_gnu_java_security_action_SetAccessibleAction$sub_refs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs	_jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$refs	_jc_gnu_java_security_action_SetAccessibleAction$refs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$nonrefs	_jc_gnu_java_security_action_SetAccessibleAction$nonrefs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$object	_jc_gnu_java_security_action_SetAccessibleAction$object;

typedef const struct _jc_gnu_java_security_action_SetAccessibleAction$vmethods	_jc_gnu_java_security_action_SetAccessibleAction$vmethods;
typedef const struct _jc_gnu_java_security_action_SetAccessibleAction$vtable	_jc_gnu_java_security_action_SetAccessibleAction$vtable;
typedef const struct _jc_gnu_java_security_action_SetAccessibleAction$vtype	_jc_gnu_java_security_action_SetAccessibleAction$vtype;

// Constructors
extern void _jc_gnu_java_security_action_SetAccessibleAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *);
extern void _jc_gnu_java_security_action_SetAccessibleAction$method$_init$402d6c9fb1b445aa(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *, struct _jc_java_lang_reflect_AccessibleObject$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_action_SetAccessibleAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *);
extern struct _jc_gnu_java_security_action_SetAccessibleAction$object *_jc_gnu_java_security_action_SetAccessibleAction$method$setMember$1555463168257bcc(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *, struct _jc_java_lang_reflect_AccessibleObject$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_action_SetAccessibleAction$method_info$run$b190d7b16d5785b8;
extern _jc_method _jc_gnu_java_security_action_SetAccessibleAction$method_info$setMember$1555463168257bcc;

// Virtual methods structure
struct _jc_gnu_java_security_action_SetAccessibleAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *);
	struct _jc_gnu_java_security_action_SetAccessibleAction$object	*(*setMember$1555463168257bcc)(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *, struct _jc_java_lang_reflect_AccessibleObject$object *);
};

// Vtable
struct _jc_gnu_java_security_action_SetAccessibleAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_action_SetAccessibleAction$vmethods	gnu_java_security_action_SetAccessibleAction;
};

// Vtype
struct _jc_gnu_java_security_action_SetAccessibleAction$vtype {
	_jc_type			type;
	_jc_gnu_java_security_action_SetAccessibleAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_action_SetAccessibleAction$sub_refs {
	struct _jc_java_lang_reflect_AccessibleObject$object	*member;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_action_SetAccessibleAction$refs {
    _jc_gnu_java_security_action_SetAccessibleAction$sub_refs	gnu_java_security_action_SetAccessibleAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_action_SetAccessibleAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs	gnu_java_security_action_SetAccessibleAction;
};

// Object instance structure
struct _jc_gnu_java_security_action_SetAccessibleAction$object {
	_jc_gnu_java_security_action_SetAccessibleAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_action_SetAccessibleAction$vtype	*vtype;
	_jc_gnu_java_security_action_SetAccessibleAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_action_SetAccessibleAction$vtype _jc_gnu_java_security_action_SetAccessibleAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_action_SetAccessibleAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_action_SetAccessibleAction$class_object;

#endif	/* _JC_gnu_java_security_action_SetAccessibleAction_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/action/SetAccessibleAction.h <==
// public class gnu.java.security.action.SetAccessibleAction

// class file dependencies
// @dep_class a46aa76484d70b7e gnu_java_security_action_SetAccessibleAction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_action_SetAccessibleAction_H_
#define _JC_gnu_java_security_action_SetAccessibleAction_H_

// Forward structure declarations
struct _jc_gnu_java_security_action_SetAccessibleAction$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_reflect_AccessibleObject$object;

// Typedefs
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$sub_refs	_jc_gnu_java_security_action_SetAccessibleAction$sub_refs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs	_jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$refs	_jc_gnu_java_security_action_SetAccessibleAction$refs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$nonrefs	_jc_gnu_java_security_action_SetAccessibleAction$nonrefs;
typedef struct _jc_gnu_java_security_action_SetAccessibleAction$object	_jc_gnu_java_security_action_SetAccessibleAction$object;

typedef const struct _jc_gnu_java_security_action_SetAccessibleAction$vmethods	_jc_gnu_java_security_action_SetAccessibleAction$vmethods;
typedef const struct _jc_gnu_java_security_action_SetAccessibleAction$vtable	_jc_gnu_java_security_action_SetAccessibleAction$vtable;
typedef const struct _jc_gnu_java_security_action_SetAccessibleAction$vtype	_jc_gnu_java_security_action_SetAccessibleAction$vtype;

// Constructors
extern void _jc_gnu_java_security_action_SetAccessibleAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_action_SetAccessibleAction$method$_init$402d6c9fb1b445aa(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_action_SetAccessibleAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_security_action_SetAccessibleAction$object *_jc_gnu_java_security_action_SetAccessibleAction$method$setMember$1555463168257bcc(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_action_SetAccessibleAction$method_info$run$b190d7b16d5785b8;
extern _jc_method _jc_gnu_java_security_action_SetAccessibleAction$method_info$setMember$1555463168257bcc;

// Virtual methods structure
struct _jc_gnu_java_security_action_SetAccessibleAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_security_action_SetAccessibleAction$object	*(*setMember$1555463168257bcc)(_jc_env *, struct _jc_gnu_java_security_action_SetAccessibleAction$object *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_action_SetAccessibleAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_action_SetAccessibleAction$vmethods	gnu_java_security_action_SetAccessibleAction;
};

// Vtype
struct _jc_gnu_java_security_action_SetAccessibleAction$vtype {
	_jc_type			type;
	_jc_gnu_java_security_action_SetAccessibleAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_action_SetAccessibleAction$sub_refs {
	struct _jc_java_lang_reflect_AccessibleObject$object	*member;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_action_SetAccessibleAction$refs {
    _jc_gnu_java_security_action_SetAccessibleAction$sub_refs	gnu_java_security_action_SetAccessibleAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_action_SetAccessibleAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_action_SetAccessibleAction$sub_nonrefs	gnu_java_security_action_SetAccessibleAction;
};

// Object instance structure
struct _jc_gnu_java_security_action_SetAccessibleAction$object {
	_jc_gnu_java_security_action_SetAccessibleAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_action_SetAccessibleAction$vtype	*vtype;
	_jc_gnu_java_security_action_SetAccessibleAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_action_SetAccessibleAction$vtype _jc_gnu_java_security_action_SetAccessibleAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_action_SetAccessibleAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_action_SetAccessibleAction$class_object;

#endif	/* _JC_gnu_java_security_action_SetAccessibleAction_H_ */
